Skip to main contentCrate kayle_innate
Source - celestial_blessing
- try to fix all possible issues using a spec against the tree.
- divine_judgement
- Perform the a judgement against a page to determine effort, access, and more.
- kayle
- perform an audit based on tree rules using dom APIs at runtime with speed.
- radiant_blast
- setup a structure tree alg for parsing and find links in document. Allow user to perform hybrid audits realtime.
- starfire_spellblade
- use gpu to accelerate layout rendering or workers.